<?php
namespace Modules\Cotacao\Modules\Pedido\Controllers;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;

class ControlePedidoColetaRelatorios extends \Zeedhi\Framework\Controller\Report {
    protected $reportService;
    protected $birtStrategy;
    protected $environment;
    protected $qr2Strategy;
    protected $connection;
    protected $repParam;
    
    
    public function __construct($reportService, $birtStrategy, $environment, $qr2Strategy, $connection, $newCode) {
        $this->reportService     = $reportService;
        $this->birtStrategy      = $birtStrategy;
        $this->environment       = $environment;
        $this->qr2Strategy       = $qr2Strategy;
        $this->connection        = $connection;
        $this->newCode           = $newCode;
        $this->repParam = array ();
    }
    
    protected $reportMapping = array ();
        
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response)
    {   
        $row = $request->getRow();
        $row['P_CDPRODFIN'] = str_pad($row['P_CDPRODFIN'], 10, 'Z');
        $row['NRORG'] = $this->environment->getNrOrg();
        
        if ($row['REPORT_NAME'] == "LIB03711" || $row['REPORT_NAME'] == 'LIB03712') {
            $row['STRATEGY'] = 'QR2';
            $this->qr2Strategy->setQr2Type($row['QR2TYPE']);
        } else {
            $row['STRATEGY'] = 'BIRT';
            $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
        }
        
        if($row['STRATEGY'] == 'BIRT'){
            if($row['L_CDOPERADOR'] != 'T'){
                $nrlistaOper = $this->criarListaValores($row['L_CDOPERADOR']);
                $row['L_CDOPERADOR'] = "_NRLISTA=".$nrlistaOper;
            }
            if($row['L_CDFORNECED'] != 'T'){
                $nrlistaForn = $this->criarListaValores($row['L_CDFORNECED']);
                $row['L_CDFORNECED'] = "_NRLISTA=".$nrlistaForn;
            }
            if($row['L_CDREGIAO'] != 'T'){
                $nrlistaReg = $this->criarListaValores($row['L_CDREGIAO']);
                $row['L_CDREGIAO'] = "_NRLISTA=".$nrlistaReg;
            }
        }
        
        $this->stNomeRel = $this->getReportName($row);

        $this->reportMapping[$this->stNomeRel] = array(
            'strategy' => $row['STRATEGY'],
            'parameterMapping' => 
            array (
                "P_CDFILIAL"        => "P_CDFILIAL",
                "L_CDOPERADOR"      => "L_CDOPERADOR",
                "L_CDREGIAO"        => "L_CDREGIAO",
                "L_CDFORNECED"      => "L_CDFORNECED",
                "P_DTINI"           => "P_DTINI",
                "P_DTFIN"           => "P_DTFIN",
                "P_CDPRODINI"       => "P_CDPRODINI",
                "P_CDPRODFIN"       => "P_CDPRODFIN",
                "P_TEXTPRODFIN"     => "P_TEXTPRODFIN",
                "P_TCDPRODUTO"      => "P_TCDPRODUTO",
                "P_TPROD"           => "P_TPROD",
                "L_SITUACAO"        => "P_SITUACAO",
                "NRORG"             => "P_NRORG"
            )
        );
    }
    
    protected function criarListaValores($lista){
        $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrOrg());
        $valores = explode('_',$lista);
        try{
            foreach($valores as $key){
                $this->insertLista($nrlista, $key);
            }
            return $nrlista;
        } catch(\Exception $e){
            throw $e;
        }
    }

    public function insertLista($nrlista, $cdlista) {
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista
        );
        
        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
}